/*****************************************************************************
 * VLCAboutViewController.h
 * VLC for iOS
 *****************************************************************************
 * Copyright (c) 2013-2014 VideoLAN. All rights reserved.
 * $Id$
 *
 * Authors: Felix Paul Kühne <fkuehne # videolan.org>
 *          Gleb Pinigin <gpinigin # gmail.com>
 *
 * Refer to the COPYING file of the official project for license.
 *****************************************************************************/

@import UIKit;
@import WebKit;

@interface VLCAboutViewController : UIViewController <WKNavigationDelegate>

@end
